/* LED8x8_MAX7219_LedControl_4
 * Az SPI buszra felfűzött MAX7219 meghajtókkal vezérelt
 * 8x8-as LED mátrixok meghajtása.
 * Az inicializálás után előre megadott szöveget görgetünk a
 * kijelzőkön.
 * A MAX7219 vezérlése szofveres SPI meghajtással és a LedControl
 * programkönyvtár függvényeivel történik.
 */
#include "LedControl.h"
#include "english_6x8_pixel.h"

#define DATA_PIN    P2_3        // data for AS1106
#define CLOCK_PIN   P2_5        // clock for AS1106
#define LOAD_PIN    P2_4        // load CS for AS1106
#define NDISP 4                 //A felfűzött modulok száma
#define NROWS 32                //A pixelsorok száma (8*NDISP) 
const char line1[] = "LED8x8_MAX7219_LedControl_4 example program ";
LedControl lc=LedControl(DATA_PIN, CLOCK_PIN, LOAD_PIN, NDISP);

void setup() {
  delay(2000);
  pinMode(DATA_PIN,OUTPUT);
  pinMode(CLOCK_PIN,OUTPUT);
  pinMode(LOAD_PIN,OUTPUT);
  digitalWrite(LOAD_PIN,HIGH);
  lc.init();
  for(int i=0; i<NDISP; i++) {
    lc.shutdown(i,false);
    lc.setIntensity(i,10);
    lc.clearDisplay(i);
  }
}

void loop() {
  showText((char*)line1);
}

void scrollinRow(int data) {
  int a0,a1,r0,r1;
  for(int r=0; r<NROWS-1; r++) {
    a0 = r>>3;
    a1 = (r+1)>>3;
    r0 = r&0x07;
    r1 = (r+1)&0x07;
    lc.setRow(a0,r0,lc.getRow(a1,r1));
  }  
  lc.setRow(NDISP-1,7,data);
}  

void writeChar(char ch) {
  ch -= 32;             //Start numbering from space
  for (int line=0; line<6; line++) {
    scrollinRow(font6x8[ch][line]); //write ont row
    delay(100);
  }
} 

void showText(const char *s) {
  while(*s) {
    writeChar(*s);
    s++;
  }  
}


