/* LED8x8_MAX7219_cascaded
 * Az SPI buszra felfűzött MAX7219 meghajtókkal vezérelt
 * 8x8-as LED mátrixok meghajtása.
 * Az inicializálás után előre megadott szöveget görgetünk a
 * kijelzőkön.
 * A MAX7219 vezérlése szofveres SPI meghajtással (lásd shiftOUT() 
 * függvény) történik. A program könnyen módosítható hardveres támogatású
 * SPI kezeléshez.
 */

#include "english_6x8_pixel.h" 

const int SPI_CS  = P2_4;                   //SPI Chip select    (LED CS bemenetre)
const int SPI_DIN = P2_3;                   //SPI MOSI adatvonal (LED DIN bemenetre)
const int SPI_CLK = P2_5;                   //SPI CLK órajel     (LED CLK bemenetre)
#define NDISP 3                             //A felfűzött modulok száma
#define NROWS 24                            //A pixelsorok száma (8 * NDISP) 

unsigned char pixels[NROWS];                //Bitkép tároló

void setup() {
  pinMode(SPI_CS,OUTPUT);                   //SPI_CS kimenet inicializálása
  digitalWrite(SPI_CS,HIGH);
  pinMode(SPI_CLK,OUTPUT);                  //SPI_CLK kimenet inicializálása
  digitalWrite(SPI_CLK,LOW);  
  pinMode(SPI_DIN,OUTPUT);                  //SPI_DIN kimenet inicializálása
  digitalWrite(SPI_DIN,LOW); 
  Init_MAX7219();                           //LED vezérlő bekonfigurálása
  for(int i=0; i<NROWS; i++) {
    pixels[i] = 0;
  }  
}

void loop() {
  showText("Hobbielektronika csoport ");
  showText("Debreceni Megtestesules Plebania ");
}

void scrollinRow(int data) {
  for(int r=0; r<NROWS; r++) {
    pixels[r]=pixels[r+1];
    pixels[NROWS-1]=data;   
  }  
  for(int r=1; r<9; r++) {
    digitalWrite(SPI_CS,LOW);
    for(int i=r-1; i<NROWS; i +=8) {
      shiftOut(SPI_DIN,SPI_CLK,MSBFIRST,r);  
      shiftOut(SPI_DIN,SPI_CLK,MSBFIRST,pixels[i]);   
    }
    digitalWrite(SPI_CS,HIGH);
  }         
}  

void writeChar(char ch) {
  ch -= 32;             //Start numbering from space
  for (int line=0; line<6; line++) {
    scrollinRow(font6x8[ch][line]); //write ont row
    delay(100);
  }
} 

void showText(char *s) {
  while(*s) {
    writeChar(*s);
    s++;
  }  
}

/* Két bájt kiküldése */
void SPI_Write2(unsigned char MSB, unsigned char LSB) 
{
  digitalWrite(SPI_CS,LOW);
  for(int i=0; i<NDISP; i++) {
    shiftOut(SPI_DIN,SPI_CLK,MSBFIRST,MSB);  
    shiftOut(SPI_DIN,SPI_CLK,MSBFIRST,LSB);  
  }
  digitalWrite(SPI_CS,HIGH);   
}

/* A LED vezérlő IC konfigurálása */
void Init_MAX7219(void)
{
  SPI_Write2(0x09, 0x00);       //Dekódolást kikapcsolni
  SPI_Write2(0x0A, 0x08);       //Közepes fényerő beállítása
  SPI_Write2(0x0B, 0x07);       //Pásztázási korlát beállítása
  SPI_Write2(0x0C, 0x01);       //Megjelenítési mód beállítása
  SPI_Write2(0x0F, 0x00);       //Display teszt tiltás  
  SPI_Write2(0x01, 0x00);       //0. sor törlése
  SPI_Write2(0x02, 0x00);       //1. sor törlése
  SPI_Write2(0x03, 0x00);       //2. sor törlése
  SPI_Write2(0x04, 0x00);       //3. sor törlése
  SPI_Write2(0x05, 0x00);       //4. sor törlése
  SPI_Write2(0x06, 0x00);       //5. sor törlése
  SPI_Write2(0x07, 0x00);       //6. sor törlése
  SPI_Write2(0x08, 0x00);       //7. sor törlése
}






